==> recital-0.4.0.tar.gz: recital-0.4.0/recital/api/indexing_tasks/indexing_task_delete.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Dict[str, Any]:
    url = "{}/api/v1/tasks/indexing/{indexing_task_id}/".format(client.base_url, indexing_task_id=indexing_task_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[None, None, None, None, HTTPValidationError]]:
    if response.status_code == 204:
        response_204 = None

        return response_204
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Response[Union[None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        indexing_task_id=indexing_task_id,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Optional[Union[None, None, None, None, HTTPValidationError]]:
    """Deletes an indexing task.

    By default all users with granted permissions can perform this operation."""

    return sync_detailed(
        client=client,
        indexing_task_id=indexing_task_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Response[Union[None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        indexing_task_id=indexing_task_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Optional[Union[None, None, None, None, HTTPValidationError]]:
    """Deletes an indexing task.

    By default all users with granted permissions can perform this operation."""

    return (
        await asyncio_detailed(
            client=client,
            indexing_task_id=indexing_task_id,
        )
    ).parsed

==> recital-0.6.0.tar.gz: recital-0.6.0/recital/api/indexing_tasks/indexing_task_delete.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Dict[str, Any]:
    url = "{}/api/v1/tasks/indexing/{indexing_task_id}/".format(client.base_url, indexing_task_id=indexing_task_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[HTTPValidationError, None]]:
    if response.status_code == 204:
        response_204 = None

        return response_204
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[HTTPValidationError, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Response[Union[HTTPValidationError, None]]:
    kwargs = _get_kwargs(
        client=client,
        indexing_task_id=indexing_task_id,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Optional[Union[HTTPValidationError, None]]:
    """Deletes an indexing task.

    By default all users with granted permissions can perform this operation."""

    return sync_detailed(
        client=client,
        indexing_task_id=indexing_task_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Response[Union[HTTPValidationError, None]]:
    kwargs = _get_kwargs(
        client=client,
        indexing_task_id=indexing_task_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    indexing_task_id: int,
) -> Optional[Union[HTTPValidationError, None]]:
    """Deletes an indexing task.

    By default all users with granted permissions can perform this operation."""

    return (
        await asyncio_detailed(
            client=client,
            indexing_task_id=indexing_task_id,
        )
    ).parsed
